pub struct BatchSwapStep {
pub pool_id: u64,
pub token_in: String,
pub token_out: String,
}Fields
pool_id: u64token_in: Stringtoken_out: StringTrait Implementations
Sourceimpl Clone for BatchSwapStep
impl Clone for BatchSwapStep
Sourcefn clone(&self) -> BatchSwapStep
fn clone(&self) -> BatchSwapStep
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BatchSwapStep
impl Debug for BatchSwapStep
Sourceimpl<'de> Deserialize<'de> for BatchSwapStep
impl<'de> Deserialize<'de> for BatchSwapStep
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BatchSwapStep
impl JsonSchema for BatchSwapStep
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BatchSwapStep
impl PartialEq for BatchSwapStep
Sourceimpl Serialize for BatchSwapStep
impl Serialize for BatchSwapStep
impl StructuralPartialEq for BatchSwapStep