pub struct ExecutedOperation {
pub operation: Operation,
pub amounts_out: Vec<Coin>,
pub amounts_in: Vec<Coin>,
pub fees: Vec<Coin>,
}Fields
operation: Operationamounts_out: Vec<Coin>amounts_in: Vec<Coin>fees: Vec<Coin>Trait Implementations
Sourceimpl Clone for ExecutedOperation
impl Clone for ExecutedOperation
Sourcefn clone(&self) -> ExecutedOperation
fn clone(&self) -> ExecutedOperation
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExecutedOperation
impl Debug for ExecutedOperation
Sourceimpl<'de> Deserialize<'de> for ExecutedOperation
impl<'de> Deserialize<'de> for ExecutedOperation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ExecutedOperation
impl JsonSchema for ExecutedOperation
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ExecutedOperation
impl PartialEq for ExecutedOperation
Sourceimpl Serialize for ExecutedOperation
impl Serialize for ExecutedOperation
impl StructuralPartialEq for ExecutedOperation