pub struct FilterApplicableSolverOrdersResponse {
pub applicable_orders: Vec<u64>,
}Fields
applicable_orders: Vec<u64>Trait Implementations
Sourceimpl Clone for FilterApplicableSolverOrdersResponse
impl Clone for FilterApplicableSolverOrdersResponse
Sourcefn clone(&self) -> FilterApplicableSolverOrdersResponse
fn clone(&self) -> FilterApplicableSolverOrdersResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for FilterApplicableSolverOrdersResponse
impl<'de> Deserialize<'de> for FilterApplicableSolverOrdersResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FilterApplicableSolverOrdersResponse
impl JsonSchema for FilterApplicableSolverOrdersResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for FilterApplicableSolverOrdersResponse
impl PartialEq for FilterApplicableSolverOrdersResponse
Sourcefn eq(&self, other: &FilterApplicableSolverOrdersResponse) -> bool
fn eq(&self, other: &FilterApplicableSolverOrdersResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for FilterApplicableSolverOrdersResponse