pub struct ZeroImpactJoinAssetToNestedResponse {
pub base_amount_in: Coin,
pub base_amount_to_join: Coin,
pub y_amounts_out: Vec<Coin>,
pub stake_fee: Coin,
pub stake_c_asset: Coin,
pub yamm_swap_fee: Vec<Coin>,
pub yamm_protocol_fee: Vec<Coin>,
pub yamm_lpt: Coin,
pub refract_fee: Coin,
pub nested_protocol_fee: Vec<Coin>,
pub nested_swap_fee: Vec<Coin>,
pub nested_lpt: Coin,
}Fields
base_amount_in: Coinbase_amount_to_join: Coiny_amounts_out: Vec<Coin>stake_fee: Coinstake_c_asset: Coinyamm_swap_fee: Vec<Coin>yamm_protocol_fee: Vec<Coin>yamm_lpt: Coinrefract_fee: Coinnested_protocol_fee: Vec<Coin>nested_swap_fee: Vec<Coin>nested_lpt: CoinTrait Implementations
Sourceimpl Clone for ZeroImpactJoinAssetToNestedResponse
impl Clone for ZeroImpactJoinAssetToNestedResponse
Sourcefn clone(&self) -> ZeroImpactJoinAssetToNestedResponse
fn clone(&self) -> ZeroImpactJoinAssetToNestedResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for ZeroImpactJoinAssetToNestedResponse
impl<'de> Deserialize<'de> for ZeroImpactJoinAssetToNestedResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ZeroImpactJoinAssetToNestedResponse
impl JsonSchema for ZeroImpactJoinAssetToNestedResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ZeroImpactJoinAssetToNestedResponse
impl PartialEq for ZeroImpactJoinAssetToNestedResponse
Sourcefn eq(&self, other: &ZeroImpactJoinAssetToNestedResponse) -> bool
fn eq(&self, other: &ZeroImpactJoinAssetToNestedResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ZeroImpactJoinAssetToNestedResponse